# Generated by Django 4.2 on 2023-09-04 08:25

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("django_drf_otp", "0002_populate_notification_preference"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="verificationtoken",
            name="expire_date",
        ),
    ]
