# Generated by Django 4.2 on 2024-01-19 05:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_drf_otp', '0006_verificationtoken_active_token_idx'),
    ]

    operations = [
        migrations.AlterField(
            model_name='verificationtoken',
            name='secret_chars',
            field=models.CharField(max_length=256, null=True, verbose_name='Extra secret characters'),
        ),
    ]
