# Generated by Django 4.2 on 2024-01-09 08:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_drf_otp', '0005_verificationtoken_secret_chars_and_more'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='verificationtoken',
            index=models.Index(fields=['is_active', 'token'], name='active_token_idx'),
        ),
    ]
